fars_read: Function fars_read

Description Usage Arguments Value

View source: R/week2_exercise.R

Description

This function gets as input a file name (of csv format), and and reads it to a data frame object, which is what the function returns.

Usage

1
fars_read(filename)

Arguments

filename

A character string with the file name to read. Either full path should be given, or path relative to local working directory. If file name does not exist - an Error will be returned.

Value

This function returns a data frame object of the filename that was read.


Milcat/week2 documentation built on April 17, 2020, 12:03 a.m.