fars_read_years: Function fars_read_years

Description Usage Arguments Value

View source: R/week2_exercise.R

Description

This function gets a list of years, and returns a list of tables for each year in the input argument. the table for each year include the year and the months from the relevant file of that year. The function also checks for valid data files for those years. A valid data file is a file which exists for this specific year.

Usage

1

Arguments

years

A vector of the years to be read.

Value

This function returns a list of tables - one table per year. Each table has 2 columns: MONTH and year taken from original file of that year.


Milcat/week2 documentation built on April 17, 2020, 12:03 a.m.