fars_summarize_years: Function fars_summarize_years

Description Usage Arguments Value Examples

View source: R/week2_exercise.R

Description

This function gets as input a list of years, and gives a summary of how many motor crashes there were in each month of each year in USA (taken from relevant files for those years).

Usage

1

Arguments

years

A vector of the years to be read.

Value

This function returns data frame with a "MONTH" column, and one columns per each year in the "years" input argument. The values under each year column - is the number of motor crashes that happeded in that year - for this specific month.

Examples

1
2
fars_summarize_years(c("2014","2015"))
fars_summarize_years(c(2015,2013))

Milcat/week2 documentation built on April 17, 2020, 12:03 a.m.