make_filename: Function make_filename

Description Usage Arguments Value

View source: R/week2_exercise.R

Description

This function gets as input a year number (in any format), and outputs the relevant data file name for that year

Usage

1

Arguments

year

Any format of 4 digits year number.

Value

This function returns a string of the relevant file name fo the specific year.


Milcat/week2 documentation built on April 17, 2020, 12:03 a.m.