Description Usage Arguments Value Examples
View source: R/week2_exercise.R
This function gets as input a state number (in USA) and a year. Its output is a map of this state with points located at the geographical location of motor crashes that happened in that state in that year. Note that invalid year (where no file exists for that year), or invalid state number will give an appropriate error.
1 | fars_map_state(state.num, year)
|
state.num |
The state number in USA. |
year |
The year number |
This function returns a map of the specific state with all motor crash locations That happened in the specific year in that state. All data is taken from relevant file.
1 2 | fars_map_state(1,2015)
fars_map_state(18,"2013")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.