Description Usage Arguments Value
View source: R/week2_exercise.R
This function gets as input a file name (of csv format), and and reads it to a data frame object, which is what the function returns.
1 | fars_read(filename)
|
filename |
A character string with the file name to read. Either full path should be given, or path relative to local working directory. If file name does not exist - an Error will be returned. |
This function returns a data frame object of the filename that was read.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.