Description Usage Arguments Value
View source: R/week2_exercise.R
This function gets a list of years, and returns a list of tables for each year in the input argument. the table for each year include the year and the months from the relevant file of that year. The function also checks for valid data files for those years. A valid data file is a file which exists for this specific year.
1 | fars_read_years(years)
|
years |
A vector of the years to be read. |
This function returns a list of tables - one table per year. Each table has 2 columns: MONTH and year taken from original file of that year.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.