Description Usage Arguments Value Examples
View source: R/week2_exercise.R
This function gets as input a list of years, and gives a summary of how many motor crashes there were in each month of each year in USA (taken from relevant files for those years).
1 | fars_summarize_years(years)
|
years |
A vector of the years to be read. |
This function returns data frame with a "MONTH" column, and one columns per each year in the "years" input argument. The values under each year column - is the number of motor crashes that happeded in that year - for this specific month.
1 2 | fars_summarize_years(c("2014","2015"))
fars_summarize_years(c(2015,2013))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.