Description Usage Arguments Value
View source: R/week2_exercise.R
This function gets as input a year number (in any format), and outputs the relevant data file name for that year
1 | make_filename(year)
|
year |
Any format of 4 digits year number. |
This function returns a string of the relevant file name fo the specific year.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.